@@ -351,3 +351,24 @@ test_that("Zbeta_Zscore calculates Zbeta_Zscore statistic correctly with missing
                                 NA,NA,NA,NA)
                ),tolerance=0.0001)
 })
+
+## test what happens when the biggest bin is bigger than the max_dist in the LDprofile
+
+df1<-df
+df1$dist[10:15]<-df1$dist[10:15]+0.1
+test_that("Zbeta_Zscore calculates Zbeta_Zscore statistic correctly when biggest bin is bigger than LDprofile", {
+
+  expect_equal(Zbeta_Zscore(pos = df1$POS, ws  = 3000, x = as.matrix(df1[,3:7]), dist = df1$dist, LDprofile_bins = LDprofile$bin, LDprofile_rsq = LDprofile$rsq, LDprofile_sd = LDprofile$sd, minRandL = 4, minRL = 25, X = NULL),
+               list(
+                 position=c(100,200,300,400,500,600,700,800,900,1000,1100,1200,1300,1400,1500),
+                 Zbeta_Zscore=c(NA,NA,NA,NA,
+                                -0.155023529432353,
+                                -0.185399969976716,
+                                -0.168250652582989,
+                                -0.104627764295373,
+                                -0.0955723675990356,
+                                -0.0601070717071691,
+                                -0.0618178441622676,
+                                NA,NA,NA,NA)
+               ),tolerance=0.0001)
+})
