@@ -247,3 +247,25 @@ test_that("Zbeta_expected fails when LDprofile_bins and LDprofile_rsq are differ
   expect_error(Zbeta_expected(pos = df$POS, ws  = 3000, dist = df$dist, LDprofile_bins = LDprofile$bin, LDprofile_rsq = c(LDprofile$rsq,1), minRandL = 4, minRL = 25, X = NULL),
                "LDprofile_rsq must contain the same number of values as there are bins given in LDprofile_bins")
 })
+
+## test what happens when the biggest bin is bigger than the max_dist in the LDprofile
+
+df1<-df
+df1$dist[10:15]<-df1$dist[10:15]+0.1
+test_that("Zbeta_expected calculates Zbeta_expected statistic correctly when biggest bin is bigger than LDprofile", {
+
+  expect_equal(Zbeta_expected(pos = df1$POS, ws  = 3000, dist = df1$dist, LDprofile_bins = LDprofile$bin, LDprofile_rsq = LDprofile$rsq, minRandL = 4, minRL = 25, X = NULL),
+               list(
+                 position=c(100,200,300,400,500,600,700,800,900,1000,1100,1200,1300,1400,1500),
+                 Zbeta_expected=c(NA,NA,NA,NA,
+                                  0.309796639287645,
+                                  0.306356600239621,
+                                  0.299229117644403,
+                                  0.287619092597206,
+                                  0.271195118636169,
+                                  0.271195118636169,
+                                  0.285239698673566,
+                                  NA,NA,NA,NA)
+               ),tolerance=0.0001)
+})
+
